@@ -16,7 +16,7 @@
 
 # Copyrights (C)
 # for this R-port: 
-#   1999 - 2004, Diethelm Wuertz, GPL
+#   1999 - 2007, Diethelm Wuertz, GPL
 #   Diethelm Wuertz <wuertz@itp.phys.ethz.ch>
 #   info@rmetrics.org
 #   www.rmetrics.org
@@ -29,18 +29,16 @@
 
 ################################################################################
 # PART I - FUNCTION:      SPECIFICATION: 
-#  setClass[garchSpec]     S4: garchSpec Class representation 
+#  'garchSpec'             S4: garchSpec Class representation 
 #  garchSpec               S4: Creates a 'garchSpec' object from scratch
-#  print.garchSpec         S3: Print method for an object of class 'garchSpec'
-#  .garchSpecRUnit         RUnit Testing
+#  show.garchSpec          S4: Print method for an object of class 'garchSpec'
 ################################################################################
 # PART II - FUNCTION:     SIMULATION:
 #  garchSim                Simulates a GARCH/APARCH process
 #  .garchSim               Simulates a GARCH/APARCH from specification object
-#  .garchSimRUnit          RUnit Testing
 ################################################################################
 # PART III - FUNCTION:    PARAMETER ESTIMATION: 
-#  setClass[fGARCH]        S4: fGARCH Class representation   
+#  'fGARCH'                S4: fGARCH Class representation   
 #  garchFit                Fits GARCH and APARCH processes
 #  .garchFit               ... old Version
 #  .garchInitSeries        Initializes Series
@@ -53,15 +51,15 @@
 #  .garchNames              Slot names, @fit slot, parameters and controls
 #  .garchTsFit             Wrapper for 'garch()' from 'tseries' package
 # METHODS:                DESCRIPTION:
-#  print.fGARCH            S3 Print method for an object of class fGARCH
-#  summary.fGARCH          S3 Summary method for an object of class fGARCH
-#  plot.fGARCH             S3 Plot method for an object of class fGARCH
+#  show.fGARCH             S4 print method for an object of class 'fGARCH'
+#  summary.fGARCH          S3 summary method for an object of class 'fGARCH'
+#  plot.fGARCH             S3 plot method for an object of class 'fGARCH'
 #  .interactiveGarchPlot   Utility Function
-#  residuals.fGARCH        S3 Residuals method for an object of class fGARCH
-#  fitted.fGARCH           S3 Fitted values method for an object of class fGARCH
-#  predict.fGARCH          S3 Prediction method for an object of class fGARCH
+#  residuals.fGARCH        S3 residuals method for an object of class 'fGARCH'
+#  fitted.fGARCH           S3 fitted values for an object of class 'fGARCH'
+#  predict.fGARCH          S3 prediction method for an object of class 'fGARCH'
 # STATISTICS:             Description:
-#  .truePersistence        Compute Persistence
+#  .truePersistence        Compute persistence
 ################################################################################
 # PART IV - FUNCTION:     FORECASTING: 
 #  garchKappa               Computes Expection for APARCH Models
@@ -69,15 +67,6 @@
 ################################################################################
 
 
-################################################################################
-# FUNCTION:              SPECIFICATION: 
-#  setClass[garchSpec]    S4: garchSpec Class representation 
-#  garchSpec              S4: Creates a 'garchSpec' object from scratch
-#  print.garchSpec        S3: Print method for an object of class 'garchSpec'
-#  .garchSpecRUnit        RUnit Testing
-################################################################################
-
-
 setClass("garchSpec", 
     representation(
         call = "call",
@@ -212,7 +201,7 @@ presample = NULL, cond.dist = c("rnorm", "rged", "rstd", "rsnorm",
         if (distribution == "rstd")   model$skew = c(skew = NULL)
         if (distribution == "rsnorm") model$skew = c(skew = 0.9)
         if (distribution == "rsged")  model$skew = c(skew = 0.9)
-        if (distribution == "rssdt")  model$skew = c(skew = 0.9) 
+        if (distribution == "rsstd")  model$skew = c(skew = 0.9) 
     } else { 
         names(model$skew) = "skew" 
     }
@@ -222,7 +211,7 @@ presample = NULL, cond.dist = c("rnorm", "rged", "rstd", "rsnorm",
         if (distribution == "rstd")   model$shape = c(shape = 4)
         if (distribution == "rsnorm") model$shape = c(shape = NULL)
         if (distribution == "rsged")  model$shape = c(shape = 2)
-        if (distribution == "rssdt")  model$shape = c(shape = 4) 
+        if (distribution == "rsstd")  model$shape = c(shape = 4) 
     } else { 
         names(model$shape) = "shape" 
     }
@@ -317,19 +306,20 @@ presample = NULL, cond.dist = c("rnorm", "rged", "rstd", "rsnorm",
 # ------------------------------------------------------------------------------
 
 
-print.garchSpec =
-function(x, ...)
+show.garchSpec =
+function(object)
 {   # A function implemented by Diethelm Wuertz
 
     # Description:
-    #   S3 Print Method for objects of class 'garchSpec'
+    #   S4 Print Method for objects of class 'garchSpec'
     
     # Arguments:
-    #   x - Object of class 'garchSpec'
+    #   object - Object of class 'garchSpec'
     
     # FUNCTION:
     
     # Formula:
+    x = object
     cat("\nFormula: \n ")
     cat(as.character(x@formula))
     
@@ -385,95 +375,9 @@ function(x, ...)
     # Return Value:
     invisible()
 }
-
-
-# ------------------------------------------------------------------------------
-
-
-.garchSpecRUnit = 
-function()
-{   # A function implemented by Diethelm Wuertz
-
-    # Description:
-    #   R Unit Testing
+   
     
-    # Arguments:
-    #   none
-    
-    # FUNCTION:
-    
-    # Internal print Function:
-    Print = function(x) {
-        cat("RUnit Test:\n ")
-        print(x@call)
-        print(x)
-        cat("\n")
-    }
-    
-    # ARCH(1) - use default omega and default alpha[1]
-    Print(garchSpec(model = list())) 
-    
-    # ARCH(1) - use default omega and specify alpha
-    Print(garchSpec(model = list(alpha = 0.2))) 
-    
-    # ARCH(1) - specify omega and alpha
-    Print(garchSpec(model = list(omega = 3.0e-6, alpha = 0.3)))
-    
-    # AR(1)-ARCH(1) - use default omega/alpha and specify alpha[1]
-    Print(garchSpec(model = list(ar = 0.5))) 
-    
-    # AR([1,5])-ARCH(1) - use default omega, specify alpha and subset ar[.]
-    Print(garchSpec(model = list(ar = c(0.5,0,0,0,0.1), alpha = 0.25)))
-    
-    # ARMA(1,2)-ARCH(1) - use default omega/alpha and specify ar[1]/ma[2]
-    Print(garchSpec(model = list(ar = 0.5, ma = c(0.3, -0.3))))
-    
-    # ARMA(2,2)-ARCH(1) use default omega/alpha and specify ar[2]/ma[2]
-    Print(garchSpec(model = list(ar = c(0.5, -0.5), ma = c(0.3,-0.3))))
-    
-    # ARCH(2) - use default omega and specify alpha[2]
-    Print(garchSpec(model = list(alpha = c(0.12, 0.04))))
-    
-    # GARCH(1,1) - use just defaults
-    Print(garchSpec())
-    
-    # GARCH(1,1) - use default omega and specify alpha/beta
-    Print(garchSpec(model = list(alpha = 0.2, beta = 0.7)))
-    
-    # GARCH(1,1) - specify omega/alpha/beta
-    Print(garchSpec(model = list(omega = 1e-6, alpha = 0.1, beta = 0.8)))
-    
-    # GARCH(1,2) - use default omega and specify alpha[1]/beta[2]
-    Print(garchSpec(model = list(alpha = 0.1, beta = c(0.4, 0.4))))
-    
-    # GARCH(2,1) - use default omega and specify alpha[2]/beta[1]
-    Print(garchSpec(model = list(alpha = c(0.12, 0.04), beta = 0.08)))
-    
-    # rsnorm-ARCH(1) - use defaults with skew Normal
-    Print(garchSpec(model = list(dist = 2), cond.dist = "rsnorm"))
-    
-    # rged-ARCH(1) using default omega and alpha[1]
-    Print(garchSpec(model = list(dist = 4), cond.dist = "rged"))
-    
-    # rsged-ARCH(1) using default omega and alpha[1]
-    Print(garchSpec(model = list(dist = c(4, 2)), cond.dist = "rsged"))
-    
-    # rstd-ARCH(1) using default omega and alpha[1]
-    Print(garchSpec(model = list(dist = 4), cond.dist = "rstd"))
-    
-    # rsstd-ARCH(1) using default omega and alpha[1]
-    Print(garchSpec(model = list(dist = c(4, 2)), cond.dist = "rsstd"))
-    
-    # TS-GARCH(1,1)
-    Print(garchSpec(model = list(delta = 1)))
-    
-    # AR(1)-t-APARCH(2, 1)
-    Print(garchSpec(model = list(mu = 1.0e-4, ar = 0.5, omega = 1.0e-6, 
-        alpha = c(0.10, 0.05), gamma = c(0, 0), beta = 0.8, delta = 1.8, 
-        dist = c(nu = 4, xi = 0.5)), cond.dist = "rsstd"))
-    
-    invisible()
-}
+setMethod("show", "garchSpec", show.garchSpec)
 
 
 ################################################################################
@@ -481,7 +385,6 @@ function()
 # SIMULATION:          DESCRIPTION:
 #  garchSim             Simulates a GARCH/APARCH process
 #  .garchSim            Simulates a GARCH/APARCH from specification object
-#  .garchSimRUnit       Unit Testing
 ################################################################################
 
 
@@ -660,99 +563,6 @@ function(n = 1000, n.start = 1000, spec = garchSpec())
 }
 
 
-# ------------------------------------------------------------------------------
-
-
-.garchSimRUnit = 
-function()
-{   # A function implemented by Diethelm Wuertz
-
-    # Description:
-    #   Unit Testing
-    
-    # Arguments:
-    #   none
-    
-    # FUNCTION:
-    
-    # ARCH(1)
-    spec = garchSpec(model = list())
-    print(garchSim(n = 10, model = spec))
-    
-    # ARCH(1)
-    spec = garchSpec(model = list(alpha = 0.1))
-    print(garchSim(n = 10, model = spec))
-    
-    # ARCH(1)
-    spec = garchSpec(model = list(omega = 1e-6, alpha = 0.1))
-    print(garchSim(n = 10, model = spec))
-    
-    # AR(1)-ARCH(1)
-    spec = garchSpec(model = list(ar = 0.5)) 
-    print(garchSim(n = 10, model = spec))
-    
-    # AR([1,5])-ARCH(1)
-    spec = garchSpec(model = list(ar = c(0.5,0,0,0,0.1)))
-    print(garchSim(n = 10, model = spec))
-    
-    # ARMA(1,2)-ARCH(1)
-    spec = garchSpec(model = list(ar = 0.5, ma = c(0.3,-0.3)))
-    print(garchSim(n = 10, model = spec))
-    
-    # rsnorn-ARCH(2)
-    spec = garchSpec(model = list(alpha = c(0.12, 0.04), dist = 2/3), 
-        cond.dist = "rsnorm")
-    print(garchSim(n = 10, model = spec))
-    
-    # GARCH(1,1)
-    spec = garchSpec()
-    print(garchSim(n = 10, model = spec))
-    
-    # GARCH(1,1)
-    spec = garchSpec(model = list(alpha = 0.1, beta = 0.8))
-    print(garchSim(n = 10, model = spec))
-    
-    # GARCH(1,1)
-    spec = garchSpec(model = list(omega = 1e-6, alpha = 0.1, beta = 0.8))
-    print(garchSim(n = 10, model = spec))
-    
-    # GARCH(1,2)
-    spec = garchSpec(model = list(alpha = 0.1, beta = c(0.4, 0.4)))
-    print(garchSim(n = 10, model = spec))
-    
-    # GARCH(2,1)
-    spec = garchSpec(model = list(alpha = c(0.12, 0.04), beta = 0.08))
-    print(garchSim(n = 10, model = spec))
-    
-    # r[s]norm-GARCH(1,1)   
-    spec = garchSpec(model = list(), cond.dist = "rnorm")
-    print(garchSim(n = 10, model = spec))
-    
-    spec = garchSpec(model = list(parm = 2), cond.dist = "rsnorm")
-    print(garchSim(n = 10, model = spec))
-    
-    # r[s]ged-GARCH(1,1)
-    spec = garchSpec(model = list(parm = 4), cond.dist = "rged")
-    print(garchSim(n = 10, model = spec))
-    
-    spec = garchSpec(model = list(parm = c(4, 2)), cond.dist = "rsged")
-    print(garchSim(n = 10, model = spec))
-    
-    # r[s]std-GARCH(1,1)
-    spec = garchSpec(model = list(parm = 4), cond.dist = "rstd")
-    print(garchSim(n = 10, model = spec))
-    
-    spec = garchSpec(model = list(parm = c(4, 2)), cond.dist = "rsstd")
-    print(garchSim(n = 10, model = spec))
-    
-    # TS-GARCH(1,1)
-    spec = garchSpec(list(alpha = 0.1, delta = 1))
-    print(garchSim(n = 10, model = spec))
-    
-    invisible()
-}
-
-
 ################################################################################
 # PART III - FUNCTION:    PARAMETER ESTIMATION: 
 #  setClass[fGARCH]        S4: fGARCH Class representation   
@@ -804,24 +614,49 @@ control = list(), title = NULL, description = NULL, ...)
     # Description
     #   Fit parameters to a ARMA-GARCH model
     
+    # FUNCTION:
+    
+    # DEBUG Status:
+    .DEBUG = FALSE
+    
+    # Check formula expression dependent on data class:
+    if (class(data) == "timeSeries") {
+        formulaLength = length(formula)
+        if (formulaLength < 3) {
+            stop1 = "For timeSeries objects you must specifiy the full formula:"
+            stop2 = "e.g. formula = X ~ arma(2,1) + garch(1,1)"
+            stop(paste(stop1, stop2)) 
+        }
+    }
+    if (class(data) == "data.frame") {
+        formulaLength = length(formula)
+        if (formulaLength < 3) {
+            stop1 = "For data.frame objects you must specifiy the full formula:"
+            stop2 = "e.g. formula = X ~ arma(2,1) + garch(1,1)"
+            stop(paste(stop1, stop2)) 
+        }
+    }
+    
     # Call:
     CALL = match.call()
     
     # Get Data:
     mf = match.call(expand.dots = FALSE)
+    if (.DEBUG) print(mf)
     m = match(c("formula", "data"), names(mf), 0)
     mf = mf[c(1, m)]
     mf[[1]] = as.name(".modelSeries")
     mf$fake = FALSE
     mf$lhs = TRUE
+    if (.DEBUG) print(mf)
     x = eval(mf, parent.frame())
     x = as.vector(x[, 1])
     if (class(mf$data) == "timeSeries") names(x) = rownames(data)
-    # print(head(x))
+    if (.DEBUG) print(head(x))
     
-    # Compose Mean and variance Formula:
+    # Compose Mean and Variance Formula:
     allLabels = attr(terms(formula), "term.labels")
-    print(allLabels)
+    if (.DEBUG) print(allLabels)
     if (length(allLabels) == 2) {
         formula.mean = as.formula(paste("~", allLabels[1]))
         formula.var = as.formula(paste("~", allLabels[2]))
@@ -829,9 +664,9 @@ control = list(), title = NULL, description = NULL, ...)
         formula.mean = as.formula("~ arma(0, 0)")
         formula.var = as.formula(paste("~", allLabels[1]))
     }
-    # print(formula.mean)
-    # print(formula.var)
-    
+    if (.DEBUG) print(formula.mean)
+    if (.DEBUG) print(formula.var)
+       
     # Fit:
     ans = .garchFit(formula.mean, formula.var, series = x, init.rec, delta, 
         skew, shape, cond.dist, include.mean, include.delta, include.skew, 
@@ -911,14 +746,17 @@ control = list(), title = NULL, description = NULL, ...)
     
     # Generate Control List - Define Default Settings:
     con <- list(
+    
         # In General:
         fscale = FALSE,
         xscale = FALSE,
         algorithm = algorithm,
         llh = c("filter", "internal", "testing")[1],
+        
         # BFGS - NLMINB Algorithm:
         tol1 = 1, 
         tol2 = 1, 
+        
         # SQP Algorithm:
         MIT = 200,     # maximum number of iterations (200)
         MFV = 500,     # maximum number of function evaluations (500)
@@ -2074,8 +1912,8 @@ title = NULL, description = NULL, ...)
 ################################################################################
                 
 
-print.fGARCH = 
-function(x, ...) 
+show.fGARCH = 
+function(object) 
 {   # A function implemented by Diethelm Wuertz
     
     # Description:
@@ -2085,9 +1923,6 @@ function(x, ...)
     #   object - an object of class 'fGARCH'
     
     # FUNCTION:
-    
-    # object:
-    object = x
      
     # Title:
     cat("\nTitle:\n ")
@@ -2135,6 +1970,9 @@ function(x, ...)
 }
 
 
+setMethod("show", "fGARCH", show.fGARCH)
+
+
 # ------------------------------------------------------------------------------
 
 
@@ -2361,7 +2199,7 @@ function(x, which = "ask", ...)
     plot.7 <<- function(x, ...) {
         # 7. Residuals:
         res = residuals(x, standardize = FALSE)
-        plot(res, type = "l", main = "Residuals", col = "steelblue")
+        plot(res, type = "l", main = "Residuals", col = "steelblue", ...)
         abline(h = 0, lty = 3)
         grid()
     }   
@@ -2369,7 +2207,7 @@ function(x, which = "ask", ...)
         # 8. Conditional SDs:
         xcsd = x@sigma.t
         plot(xcsd, type = "l", main = "Conditional SD's", 
-            col = "steelblue")
+            col = "steelblue", ...)
         abline(h = 0, lty = 3)
         grid()
     }   
@@ -2377,7 +2215,7 @@ function(x, which = "ask", ...)
         # 9. Standardized Residuals:
         sres = residuals(x, standardize = FALSE)
         plot(sres, type = "l", main = "Standardized Residuals", 
-            col = "steelblue")
+            col = "steelblue", ...)
         abline(h = 0, lty = 3)
         grid()
     }       
@@ -2445,7 +2283,7 @@ function(x, which = "ask", ...)
             "plot.1",  "plot.2",  "plot.3", "plot.4", "plot.5",
             "plot.6",  "plot.7",  "plot.8", "plot.9", "plot.10",
             "plot.11", "plot.12", "plot.13"),
-        which = which) 
+        which = which, ...) 
             
     # Return Value:
     invisible(x)
